# spinWannier
**<i>Tools for handling Wannier models with a spin operator and spin-texture plotting.</i>**

If you find this package useful, please cite [L. Vojáček*, J. M. Dueñas* _et al._, Nano Letters (2024)](https://pubs.acs.org/doi/10.1021/acs.nanolett.4c03029).


## Usage 

An example of use is given in ``./examples/spinWannier_use_example.ipynb``. It uses input files of a CrTe<sub>2</sub> monolayer given in ``./examples/wannier_files_CrTe2/``.

Example plot of Fermi-surface spin textures of CrXY (X,Y=S,Se,Te) monolayers, 
as calculated in [L. Vojáček*, J. M. Dueñas* et al., Nano Letters (2024)](https://pubs.acs.org/doi/10.1021/acs.nanolett.4c03029):
<center><img src="https://github.com/user-attachments/assets/5204849c-0fa1-419f-9955-6c55c014babe" alt="spin_texture_example" width="550" /></center>
